@@ -7,7 +7,7 @@
 
 # TODO: import from Knack once it is moved
 # pylint: disable=too-few-public-methods
-class Completer(object):
+class Completer:
 
     def __init__(self, func):
         self.func = func
