@@ -14,6 +14,16 @@ from knack.util import CommandResultItem
 logger = get_logger(__name__)
 
 
+class CommandError(Exception):
+
+    def __init__(self, output, exit_code, command):
+        message = "Command `{}` failed with exit code {}:\n{}".format(command, exit_code, output)
+        self.exit_code = exit_code
+        self.output = output
+        self.command = command
+        super().__init__(message)
+
+
 def call(command, **kwargs):
     """ Run an arbitrary command but don't buffer the output.
 
@@ -27,12 +37,13 @@ def call(command, **kwargs):
         **kwargs)
 
 
-def cmd(command, message=False, show_stderr=True, **kwargs):
+def cmd(command, message=False, show_stderr=True, raise_error=False, **kwargs):
     """ Run an arbitrary command.
 
     :param command: The entire command line to run.
     :param message: A custom message to display, or True (bool) to use a default.
     :param show_stderr: On error, display the contents of STDERR.
+    :param raise_error: On error, raise CommandError.
     :param kwargs: Any kwargs supported by subprocess.Popen
     :returns: CommandResultItem object.
     """
@@ -45,23 +56,28 @@ def cmd(command, message=False, show_stderr=True, **kwargs):
     if message:
         display(message)
 
+    logger.info("Running: %s", command)
     try:
         output = subprocess.check_output(
             command.split(),
             stderr=subprocess.STDOUT if show_stderr else None,
             shell=IS_WINDOWS,
             **kwargs).decode('utf-8').strip()
+        logger.debug(output)
         return CommandResultItem(output, exit_code=0, error=None)
     except subprocess.CalledProcessError as err:
+        if raise_error:
+            raise CommandError(err.output.decode(), err.returncode, command)
         return CommandResultItem(err.output, exit_code=err.returncode, error=err)
 
 
-def py_cmd(command, message=False, show_stderr=True, is_module=True, **kwargs):
+def py_cmd(command, message=False, show_stderr=True, raise_error=False, is_module=True, **kwargs):
     """ Run a script or command with Python.
 
     :param command: The arguments to run python with.
     :param message: A custom message to display, or True (bool) to use a default.
     :param show_stderr: On error, display the contents of STDERR.
+    :param raise_error: On error, raise CommandError.
     :param is_module: Run a Python module as a script with -m.
     :param kwargs: Any kwargs supported by subprocess.Popen
     :returns: CommandResultItem object.
@@ -74,17 +90,19 @@ def py_cmd(command, message=False, show_stderr=True, is_module=True, **kwargs):
         command = '{} -m {}'.format(python_bin, command)
     else:
         command = '{} {}'.format(python_bin, command)
-    return cmd(command, message, show_stderr, **kwargs)
+    return cmd(command, message, show_stderr, raise_error, **kwargs)
 
 
-def pip_cmd(command, message=False, show_stderr=True, **kwargs):
+def pip_cmd(command, message=False, show_stderr=True, raise_error=True, **kwargs):
     """ Run a pip command.
 
     :param command: The arguments to run pip with.
     :param message: A custom message to display, or True (bool) to use a default.
     :param show_stderr: On error, display the contents of STDERR.
+    :param raise_error: On error, raise CommandError. As pip_cmd is usually called as a control function, instead of
+      a test target, default to True.
     :param kwargs: Any kwargs supported by subprocess.Popen
     :returns: CommandResultItem object.
     """
     command = 'pip {}'.format(command)
-    return py_cmd(command, message, show_stderr, **kwargs)
+    return py_cmd(command, message, show_stderr, raise_error, **kwargs)
